﻿using MbUnit.Framework;
using Rss;
using MockSubSonic;
using System;
using Rhino.Mocks;

namespace MockSubSonic.Tests
{
    [TestFixture]
    public class RSSProcessorTests
    {
        
        [Test]
        public void GetXmlFromURL()
        {
            RssFeed rss = PostManager.GetRssFeed(TestHelper.url);
            Assert.AreEqual(TestHelper.url, rss.Url);
        }

        [Test]
        public void MockGettingRssFeed()
        {
            //This is what we want our mock object to return to the calling code. 
            RssFeed rss = TestHelper.CreateMockRSS(TestHelper.url);
            MockRepository mocks = new MockRepository();
            IFeedGetter feedGetter = mocks.CreateMock<IFeedGetter>();

            using (mocks.Record())
            {
                Expect.Call(feedGetter.GetFeed(TestHelper.url)).Return(rss);
            }

            using (mocks.Playback())
            {
                PostManager.FeedGetter = feedGetter;
                RssFeed actualRss = PostManager.GetRssFeed(TestHelper.url);

                Assert.GreaterThan(rss.Channels.Count, 0);
                Assert.AreEqual(TestHelper.url, rss.Channels[0].Link.AbsoluteUri);
            }
        }
    }
}
