﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;
using Rss;

namespace MockSubSonic.Tests
{
    [TestFixture]
    public class TestHelper
    {
        internal static string url = "http://newsrss.bbc.co.uk/rss/newsonline_uk_edition/front_page/rss.xml";

        static string name = "Username1";
        static string password = "Password1";
        static string email = "Username1@EmailProvider.com";

        [Test]
        public void TestMockCreation()
        {
            RssFeed rss = CreateMockRSS(url);
            Assert.GreaterThan(rss.Channels.Count, 0);
            //Assert.AreEqual(url, rss.Url);  Problem with the understanding on the Framework,  read only getter.  Must use Channels.
            Assert.AreEqual(url, rss.Channels[0].Link.AbsoluteUri);
        }

        internal static RssFeed CreateMockRSS(string url)
        {
            RssFeed rss = new RssFeed();
            rss.Url = url;
            rss.Version = RssVersion.RSS20;

            RssItem ri1a = new RssItem();
            ri1a.Author = "News Reporter A";
            ri1a.Title = "New Item A";
            ri1a.Description = "News Story";
            ri1a.Link = new Uri("http://www.yourserver.com/");
            ri1a.PubDate = DateTime.Now;

            RssItem ri2a = new RssItem();
            ri2a.Author = "News Reporter A";
            ri2a.Title = "New Item A";
            ri2a.Description = "News Story";
            ri2a.Link = new Uri("http://www.yourserver.com/");
            ri2a.PubDate = DateTime.Now;

            RssChannel rc1 = new RssChannel();
            rc1.Items.Add(ri1a);
            rc1.Items.Add(ri2a);
            rc1.Title = "BBC News";
            rc1.Description = "BBC News RSS";
            rc1.Link = new Uri(url);
            rc1.PubDate = DateTime.Now;

            rss.Channels.Add(rc1);

            return rss;
        }


        [Test]
        public void UserCreatedCorrectly()
        {
            User u = CreateUser();
            Assert.AreEqual(u.Name, name);
            Assert.AreEqual(u.Email, email);
            Assert.AreEqual(u.Password, password);
        }

        internal static User CreateUser()
        {
            User user = new User(name, password, email);
            return user;
        }
    }
}
