﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Rss;

namespace MockSubSonic
{
    public static class DatabaseManager
    {
        private static IDataStore dataStore = new SubSonicDataStore();
        public static IDataStore DataStore
        {
            get { return dataStore; }
            set { dataStore = value; }
        }

        public static bool SaveFeed(RssFeed feed)
        {
            if (dataStore == null)
                throw new ArgumentNullException("dataStore");

            feed.Channels[0].Link = new Uri(feed.Url);

            int channelID = InsertFeedDetails(feed.Channels[0]);
            if (channelID < 0)
                return false;

            bool result = InsertFeedItems(channelID, feed.Channels[0].Items);
            return result;
        }

        public static int InsertFeedDetails(RssChannel rssChannel)
        {
            return DataStore.InsertFeedDetails(rssChannel);
        }

        public static bool InsertFeedItems(int channelID, RssItemCollection rssItemCollection)
        {
            bool result = false;
            foreach (RssItem item in rssItemCollection)
            {
                int id = DataStore.InsertFeedItem(channelID, item);
                if (id > 0)
                    result = true;
                else
                {
                    result = false;
                    break;
                }
            }
            return result;
        }

        public static RssChannel GetRssChannel(string url)
        {
            return dataStore.GetRssChannel(url);
        }

        public static RssItemCollection GetRssFeedsForChannel(int channelId)
        {
            return dataStore.GetRssItemsForChannel(channelId);
        }

        public static RssFeed GetFeed(string url)
        {
            RssFeed feed = new RssFeed();
            feed.Url = url;

            RssChannel channel = GetRssChannel(url);
            int channelId = dataStore.GetChannelIDForUrl(url);
            RssItemCollection feedItemCollection = GetRssFeedsForChannel(channelId);

            foreach (RssItem item in feedItemCollection)
            {
                channel.Items.Add(item);
            }

            feed.Channels.Add(channel);
            return feed;
        }

        public static int SaveUser(User user)
        {
            return dataStore.SaveUser(user);
        }

        public static bool SubscribeUserToFeed(string username, string url)
        {
            int channelId = dataStore.GetChannelIDForUrl(url);
            bool result = dataStore.Subscribe(username, channelId);
            return result;
        }

        public static RssFeedCollection GetUsersRssFeedCollection(string username)
        {
            RssFeedCollection feedCollection = new RssFeedCollection();
            int userId = dataStore.GetUserIDForUsername(username);
            int[] channelList = dataStore.GetChannelListForUser(userId);
            foreach (int item in channelList)
            {
                RssFeed rss = new RssFeed();
                RssChannel rssChannel = dataStore.GetRssChannel(item);
                RssItemCollection rssItems = dataStore.GetRssItemsForChannel(item);
                foreach (RssItem rssItem in rssItems)
                {
                    rssChannel.Items.Add(rssItem);
                }
                rss.Channels.Add(rssChannel);
                feedCollection.Add(rss);
            }

            return feedCollection;
        }
    }
}
