﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Rss;
using System.Data.SqlClient;
using System.Collections;

namespace MockSubSonic
{
    public class SubSonicDataStore : IDataStore
    {
        public int InsertFeedDetails(RssChannel rssChannel)
        {
            MockSubSonic.DAL.RssChannel rss = ConvertRssChannelObject(rssChannel);
            rss.Save();
            return rss.Id;
        }

        public int InsertFeedItem(int channelID, RssItem rssItem)
        {
            MockSubSonic.DAL.RssItem rss = ConvertRssItemObject(rssItem);
            rss.ChannelId = channelID;
            rss.Save();
            return rss.Id;
        }

        public MockSubSonic.DAL.RssChannel ConvertRssChannelObject(RssChannel rssChannel)
        {
            MockSubSonic.DAL.RssChannel rss = new MockSubSonic.DAL.RssChannel();
            rss.Title = rssChannel.Title;
            rss.Description = rssChannel.Description;
            rss.Uri = rssChannel.Link.AbsoluteUri;

            if (rssChannel.PubDate <= Convert.ToDateTime("01/01/1970 00:00:00"))
                rss.PubDate = Convert.ToDateTime("01/01/1970 00:00:00");
            else
                rss.PubDate = rssChannel.PubDate;
            return rss;
        }

        public MockSubSonic.DAL.RssItem ConvertRssItemObject(Rss.RssItem rssItem)
        {
            MockSubSonic.DAL.RssItem rss = new MockSubSonic.DAL.RssItem();
            rss.Title = rssItem.Title;
            rss.PubDate = rssItem.PubDate;
            rss.Link = rssItem.Link.AbsoluteUri;
            rss.Description = rssItem.Description;
            rss.Author = rssItem.Author;
            return rss;
        }

        public RssChannel GetRssChannel(string url)
        {
            SqlDataReader dr = (SqlDataReader)MockSubSonic.DAL.RssChannel.FetchByParameter(MockSubSonic.DAL.RssChannel.Columns.Uri, url);

            if (!dr.HasRows)
                throw new ArgumentException("Channel Not Found");
            dr.Read();

            RssChannel chan = new RssChannel();
            chan.Title = dr.GetString(1);
            chan.PubDate = dr.GetDateTime(2);
            chan.Description = dr.GetString(3);
            chan.Link = new Uri(dr.GetString(4));

            return chan;
        }

        public RssItemCollection GetRssItemsForChannel(int channelId)
        {
            SqlDataReader dr = (SqlDataReader)MockSubSonic.DAL.RssItem.FetchByParameter(MockSubSonic.DAL.RssItem.Columns.ChannelId, channelId);
            
            if (!dr.HasRows)
                throw new ArgumentException("Feed Items Not Found");
            
            RssItemCollection collection = new RssItemCollection();

            while (dr.Read())
            {
                RssItem item = new RssItem();
                item.Title = dr.GetString(2);
                item.PubDate = dr.GetDateTime(3);
                item.Link = new Uri(dr.GetString(4));
                item.Description = dr.GetString(5);
                item.Author = dr.GetString(6);
                collection.Add(item);
            }

            return collection;
        }

        public int GetChannelIDForUrl(string url)
        {
            SqlDataReader dr = (SqlDataReader)MockSubSonic.DAL.RssChannel.FetchByParameter(MockSubSonic.DAL.RssChannel.Columns.Uri, url);

            if (!dr.HasRows)
                throw new ArgumentException("Channel Not Found");
            dr.Read();

            return dr.GetInt32(0);
        }

        public int SaveUser(User user)
        {
            MockSubSonic.DAL.User subUser = ConvertUserObject(user);
            subUser.Save();
            return subUser.Id;
        }

        public MockSubSonic.DAL.User ConvertUserObject(User user)
        {
            MockSubSonic.DAL.User newUser = new MockSubSonic.DAL.User();
            newUser.Name = user.Name;
            newUser.Email = user.Email;
            newUser.Password = user.Password;
            return newUser;
        }

        public bool Subscribe(string username, int channelId)
        {
            MockSubSonic.DAL.UserChannelSubscription sub = new MockSubSonic.DAL.UserChannelSubscription();
            sub.ChannelId = channelId;

            sub.UserId = GetUserIDForUsername(username);

            sub.Save();

            if (sub.Id > 0)
                return true;
            else
                return false;
        }

        public int GetUserIDForUsername(string username)
        {
            SqlDataReader dr = (SqlDataReader)MockSubSonic.DAL.User.FetchByParameter(MockSubSonic.DAL.User.Columns.Name, username);

            if (!dr.HasRows)
                throw new ArgumentException("User Not Found");
            dr.Read();

            return dr.GetInt32(0);
        }

        public int[] GetChannelListForUser(int userId)
        {
            SqlDataReader dr = (SqlDataReader)MockSubSonic.DAL.UserChannelSubscription.FetchByParameter(MockSubSonic.DAL.UserChannelSubscription.Columns.UserId, userId);

            if (!dr.HasRows)
                throw new ArgumentException("User Not Found");

            List<int> list = new List<int>();

            while (dr.Read())
            {
                list.Add(dr.GetInt32(1));
            }

            return list.ToArray();
        }

        public RssChannel GetRssChannel(int channelId)
        {
            MockSubSonic.DAL.RssChannel rssChan = MockSubSonic.DAL.RssChannel.FetchByID(channelId);

            RssChannel chan = new RssChannel();
            chan.Title = rssChan.Title;
            chan.PubDate = rssChan.PubDate;
            chan.Description = rssChan.Description;
            chan.Link = new Uri(rssChan.Uri);

            return chan;
        }
    }
}
